@@ -1,4 +1,4 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
@@ -8,7 +8,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,13 +21,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
- *    Network client. Passes information to/from server, staying 
+ *    Network client. Passes information to/from server, staying
  *    synchronised.
- *    Contains the main wait loop, waiting for network input or 
+ *    Contains the main wait loop, waiting for network input or
  *    time before doing the next tic.
  *    Rewritten for LxDoom, but based around bits of the old code.
  *
@@ -39,10 +39,9 @@
 #include "d_net.h"
 #include "z_zone.h"
 
-#include "c_io.h"
 #include "d_main.h"
 #include "g_game.h"
-#include "mn_engin.h"
+#include "m_menu.h"
 
 #include "protocol.h"
 #include "i_network.h"
@@ -53,8 +52,9 @@
 #include "lprintf.h"
 
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
+#include <sys/types.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -91,29 +91,33 @@ void D_InitNetGame (void)
     playeringame[consoleplayer = 0] = true;
   } else {
     // Get game info from server
-    packet_header_t *packet = malloc(1000);
+    packet_header_t *packet = Z_Malloc(1000, PU_STATIC, NULL);
     struct setup_packet_s *sinfo = (void*)(packet+1);
-  struct { packet_header_t head; short pn; } initpacket;
+  struct { packet_header_t head; short pn; } PACKEDATTR initpacket;
 
     I_InitNetwork();
   udp_socket = I_Socket(0);
   I_ConnectToServer(myargv[i]);
-  // Send init packet
-  initpacket.pn = doom_htons(wanted_player_number);
-  initpacket.head.type = PKT_INIT; initpacket.head.tic = 0;
-  I_SendPacket(&initpacket.head, sizeof(initpacket));
 
     do
     {
-      do { I_WaitForPacket(); } while (!I_GetPacket(packet, 1000));
-      {
-        printf("type: %d\n",packet->type);
-      }
+      do { 
+	// Send init packet
+	initpacket.pn = doom_htons(wanted_player_number);
+	packet_set(&initpacket.head, PKT_INIT, 0);
+	I_SendPacket(&initpacket.head, sizeof(initpacket));
+	I_WaitForPacket(5000);
+      } while (!I_GetPacket(packet, 1000));
+      if (packet->type == PKT_DOWN) I_Error("Server aborted the game");
     } while (packet->type != PKT_SETUP);
 
+    // Once we have been accepted by the server, we should tell it when we leave
+    atexit(D_QuitNetGame);
+
     // Get info from the setup packet
     consoleplayer = sinfo->yourplayer;
     compatibility_level = sinfo->complevel;
+    G_Compatibility();
     startskill = sinfo->skill;
     deathmatch = sinfo->deathmatch;
     startmap = sinfo->level;
@@ -122,24 +126,25 @@ void D_InitNetGame (void)
     xtratics = sinfo->extratic;
     G_ReadOptions(sinfo->game_options);
 
-    lprintf(LO_INFO, "\tjoined game as player %d/%d; %d WADs specified\n", 
-	    consoleplayer+1, numplayers = sinfo->players, sinfo->numwads);
+    lprintf(LO_INFO, "\tjoined game as player %d/%d; %d WADs specified\n",
+      consoleplayer+1, numplayers = sinfo->players, sinfo->numwads);
     {
       char *p = sinfo->wadnames;
       int i = sinfo->numwads;
 
       while (i--) {
-	D_AddFile(p, source_net);
-	p += strlen(p) + 1;
+  D_AddFile(p, source_net);
+  p += strlen(p) + 1;
       }
     }
-    free(packet);
+    Z_Free(packet);
   }
   localcmds = netcmds[displayplayer = consoleplayer];
   for (i=0; i<numplayers; i++)
     playeringame[i] = true;
   for (; i<MAXPLAYERS; i++)
     playeringame[i] = false;
+  if (!playeringame[consoleplayer]) I_Error("D_InitNetGame: consoleplayer not in game");
 }
 #else
 void D_InitNetGame (void)
@@ -149,13 +154,13 @@ void D_InitNetGame (void)
   doomcom = Z_Malloc(sizeof *doomcom, PU_STATIC, NULL);
   doomcom->consoleplayer = 0;
   doomcom->numnodes = 0; doomcom->numplayers = 1;
-  localcmds = netcmds[consoleplayer]; 
+  localcmds = netcmds[consoleplayer];
 
   for (i=0; i<doomcom->numplayers; i++)
     playeringame[i] = true;
   for (; i<MAXPLAYERS; i++)
     playeringame[i] = false;
-        
+
   consoleplayer = displayplayer = doomcom->consoleplayer;
 }
 #endif // HAVE_NET
@@ -163,20 +168,20 @@ void D_InitNetGame (void)
 #ifdef HAVE_NET
 void D_CheckNetGame(void)
 {
-  packet_header_t *packet = malloc(sizeof(packet_header_t)+1);
+  packet_header_t *packet = Z_Malloc(sizeof(packet_header_t)+1, PU_STATIC, NULL);
 
   if (server) {
     lprintf(LO_INFO, "D_CheckNetGame: waiting for server to signal game start\n");
     do {
       while (!I_GetPacket(packet, sizeof(packet_header_t)+1)) {
-	packet->tic = 0; packet->type = PKT_GO; 
+        packet_set(packet, PKT_GO, 0);
 	*(byte*)(packet+1) = consoleplayer;
 	I_SendPacket(packet, sizeof(packet_header_t)+1);
 	I_uSleep(100000);
       }
     } while (packet->type != PKT_GO);
   }
-  free(packet);
+  Z_Free(packet);
 }
 
 boolean D_NetGetWad(const char* name)
@@ -190,15 +195,15 @@ boolean D_NetGetWad(const char* name)
 
   do {
     // Send WAD request to remote
-    packet = malloc(psize);
-    packet->type = PKT_WAD; packet->tic = 0;
+    packet = Z_Malloc(psize, PU_STATIC, NULL);
+    packet_set(packet, PKT_WAD, 0);
     *(byte*)(packet+1) = consoleplayer;
     strcpy(1+(byte*)(packet+1), name);
     I_SendPacket(packet, sizeof(packet_header_t) + strlen(name) + 2);
-    
+
     I_uSleep(10000);
   } while (!I_GetPacket(packet, psize) || (packet->type != PKT_WAD));
-  free(packet);
+  Z_Free(packet);
 
   if (!strcasecmp((void*)(packet+1), name)) {
     pid_t pid;
@@ -209,7 +214,7 @@ boolean D_NetGetWad(const char* name)
      * Unix systems have all these commands handy, this kind of thing is easy
      * Any windo$e port will have some awkward work replacing these.
      */
-    /* cph - caution here. This is data from an untrusted source. 
+    /* cph - caution here. This is data from an untrusted source.
      * Don't pass it via a shell. */
     if ((pid = fork()) == -1)
       perror("fork");
@@ -221,16 +226,16 @@ boolean D_NetGetWad(const char* name)
     wait(&rv);
     if (!(done = !access(name, R_OK))) {
       if (!strcmp(p+strlen(p)-4, ".zip")) {
-	p = strrchr(p, '/')+1; 
-	if ((pid = fork()) == -1)
-	  perror("fork");
-	else if (!pid) {
-	  /* Child executes decompressor */
-	  execlp("unzip", "unzip", p, name, NULL);
-	}
-	/* Parent waits for the file */
-	wait(&rv);
-	done = !!access(name, R_OK);
+  p = strrchr(p, '/')+1;
+  if ((pid = fork()) == -1)
+    perror("fork");
+  else if (!pid) {
+    /* Child executes decompressor */
+    execlp("unzip", "unzip", p, name, NULL);
+  }
+  /* Parent waits for the file */
+  wait(&rv);
+  done = !!access(name, R_OK);
       }
       /* Add more decompression protocols here as desired */
     }
@@ -251,50 +256,49 @@ void NetUpdate(void)
     while ((recvlen = I_GetPacket(packet, 10000))) {
       switch(packet->type) {
       case PKT_TICS:
-	{
-	  byte *p = (void*)(packet+1);
-	  int tics = *p++;
-	  unsigned long ptic = doom_ntohl(packet->tic);
-	  if (ptic > (unsigned)remotetic) { // Missed some
-	    packet->type = PKT_RETRANS;
-	    packet->tic = doom_htonl(remotetic);
-	    *(byte*)(packet+1) = consoleplayer;
-	    I_SendPacket(packet, sizeof(*packet)+1);
-	  } else {
-	    if (ptic + tics <= (unsigned)remotetic) break; // Will not improve things
-	    remotetic = ptic;
-	    while (tics--) {
-	      int players = *p++;
-	      while (players--) {
-		int n = *p++;
-		RawToTic(&netcmds[n][remotetic%BACKUPTICS], p);
-		p += sizeof(ticcmd_t);
-	      }
-	      remotetic++;
-	    }
-	  }
-	}
-	break;
+  {
+    byte *p = (void*)(packet+1);
+    int tics = *p++;
+    unsigned long ptic = doom_ntohl(packet->tic);
+    if (ptic > (unsigned)remotetic) { // Missed some
+      packet_set(packet, PKT_RETRANS, remotetic);
+      *(byte*)(packet+1) = consoleplayer;
+      I_SendPacket(packet, sizeof(*packet)+1);
+    } else {
+      if (ptic + tics <= (unsigned)remotetic) break; // Will not improve things
+      remotetic = ptic;
+      while (tics--) {
+        int players = *p++;
+        while (players--) {
+            int n = *p++;
+            RawToTic(&netcmds[n][remotetic%BACKUPTICS], p);
+            p += sizeof(ticcmd_t);
+        }
+        remotetic++;
+      }
+    }
+  }
+  break;
       case PKT_RETRANS: // Resend request
-	remotesend = doom_ntohl(packet->tic);
-	break;
+          remotesend = doom_ntohl(packet->tic);
+          break;
       case PKT_DOWN: // Server downed
-	{
-	  int j;
-	  for (j=0; j<MAXPLAYERS; j++)
-	    if (j != consoleplayer) playeringame[j] = false;
-	  server = false;
-	  doom_printf("Server is down\nAll other players are no longer in the game\n");
-	}
-	break;
+  {
+    int j;
+    for (j=0; j<MAXPLAYERS; j++)
+      if (j != consoleplayer) playeringame[j] = false;
+    server = false;
+    doom_printf("Server is down\nAll other players are no longer in the game\n");
+  }
+  break;
       case PKT_EXTRA: // Misc stuff
       case PKT_QUIT: // Player quit
-	// Queue packet to be processed when its tic time is reached
-	queuedpacket = Z_Realloc(queuedpacket, ++numqueuedpackets * sizeof *queuedpacket, 
-				 PU_STATIC, NULL);
-	queuedpacket[numqueuedpackets-1] = Z_Malloc(recvlen, PU_STATIC, NULL);
-	memcpy(queuedpacket[numqueuedpackets-1], packet, recvlen);
-	break;
+  // Queue packet to be processed when its tic time is reached
+  queuedpacket = Z_Realloc(queuedpacket, ++numqueuedpackets * sizeof *queuedpacket,
+         PU_STATIC, NULL);
+  queuedpacket[numqueuedpackets-1] = Z_Malloc(recvlen, PU_STATIC, NULL);
+  memcpy(queuedpacket[numqueuedpackets-1], packet, recvlen);
+  break;
       case PKT_BACKOFF:
         /* cph 2003-09-18 -
 	 * The server sends this when we have got ahead of the other clients. We should
@@ -303,7 +307,7 @@ void NetUpdate(void)
         lastmadetic++;
 	break;
       default: // Other packet, unrecognised or redundant
-	break;
+  break;
       }
     }
     Z_Free(packet);
@@ -312,6 +316,7 @@ void NetUpdate(void)
     int newtics = I_GetTime() - lastmadetic;
     newtics = (newtics > 0 ? newtics : 0);
     lastmadetic += newtics;
+    if (ffmap) newtics++;
     while (newtics--) {
       I_StartTic();
       if (maketic - gametic > BACKUPTICS/2) break;
@@ -324,27 +329,26 @@ void NetUpdate(void)
       if (remotesend < 0) remotesend = 0;
       sendtics = maketic - remotesend;
       {
-	size_t pkt_size = sizeof(packet_header_t) + 2 + sendtics * sizeof(ticcmd_t);
-	packet_header_t *packet = Z_Malloc(pkt_size, PU_STATIC, NULL);
-	
-	packet->tic = doom_htonl(maketic - sendtics);
-	packet->type = PKT_TICC;
-	*(byte*)(packet+1) = sendtics;
-	*(((byte*)(packet+1))+1) = consoleplayer;
-	{
-	  void *tic = ((byte*)(packet+1)) +2;
-	  while (sendtics--) {
-	    TicToRaw(tic, &localcmds[remotesend++%BACKUPTICS]);
-	    tic = (byte *)tic + sizeof(ticcmd_t);
-	  }
-	}
-	I_SendPacket(packet, pkt_size);
-	Z_Free(packet);
+  size_t pkt_size = sizeof(packet_header_t) + 2 + sendtics * sizeof(ticcmd_t);
+  packet_header_t *packet = Z_Malloc(pkt_size, PU_STATIC, NULL);
+
+  packet_set(packet, PKT_TICC, maketic - sendtics);
+  *(byte*)(packet+1) = sendtics;
+  *(((byte*)(packet+1))+1) = consoleplayer;
+  {
+    void *tic = ((byte*)(packet+1)) +2;
+    while (sendtics--) {
+      TicToRaw(tic, &localcmds[remotesend++%BACKUPTICS]);
+      tic = (byte *)tic + sizeof(ticcmd_t);
+    }
+  }
+  I_SendPacket(packet, pkt_size);
+  Z_Free(packet);
       }
     }
   }
 }
-#endif // HAVE_NET
+#else
 
 void D_BuildNewTiccmds()
 {
@@ -359,22 +363,22 @@ void D_BuildNewTiccmds()
       maketic++;
     }
 }
+#endif
 
 #ifdef HAVE_NET
 /* cph - data passed to this must be in the Doom (little-) endian */
-void D_NetSendMisc(netmisctype_t type, size_t len, void* data) 
+void D_NetSendMisc(netmisctype_t type, size_t len, void* data)
 {
   if (server) {
     size_t size = sizeof(packet_header_t) + 3*sizeof(int) + len;
     packet_header_t *packet = Z_Malloc(size, PU_STATIC, NULL);
     int *p = (void*)(packet+1);
-    
-    packet->tic = doom_htonl(gametic);
-    packet->type = PKT_EXTRA;
+
+    packet_set(packet, PKT_EXTRA, gametic);
     *p++ = LONG(type); *p++ = LONG(consoleplayer); *p++ = LONG(len);
     memcpy(p, data, len);
     I_SendPacket(packet, size);
-    
+
     Z_Free(packet);
   }
 }
@@ -383,35 +387,35 @@ static void CheckQueuedPackets(void)
 {
   int i;
   for (i=0; (unsigned)i<numqueuedpackets; i++)
-    if (doom_ntohl(queuedpacket[i]->tic) <= (unsigned)gametic)
+    if (doom_ntohl(queuedpacket[i]->tic) <= gametic)
       switch (queuedpacket[i]->type) {
       case PKT_QUIT: // Player quit the game
-	{
-	  int pn = *(byte*)(queuedpacket[i]+1);
-	  playeringame[pn] = false;
-	  doom_printf("Player %d left the game\n", pn);
-	}
-	break;
+  {
+    int pn = *(byte*)(queuedpacket[i]+1);
+    playeringame[pn] = false;
+    doom_printf("Player %d left the game\n", pn);
+  }
+  break;
       case PKT_EXTRA:
-	{
-	  int *p = (int*)(queuedpacket[i]+1);
-	  size_t len = LONG(*(p+2));
-	  switch (LONG(*p)) {
-	  case nm_plcolour:
-	    G_ChangedPlayerColour(LONG(*(p+1)), LONG(*(p+3)));
-	    break;
-	  case nm_savegamename:
-	    if (len < SAVEDESCLEN) {
-	      memcpy(savedescription, p+3, len);
-	      // Force terminating 0 in case
-	      savedescription[len] = 0;
-	    }
-	    break;
-	  }
-	}
-	break;
+  {
+    int *p = (int*)(queuedpacket[i]+1);
+    size_t len = LONG(*(p+2));
+    switch (LONG(*p)) {
+    case nm_plcolour:
+      G_ChangedPlayerColour(LONG(*(p+1)), LONG(*(p+3)));
+      break;
+    case nm_savegamename:
+      if (len < SAVEDESCLEN) {
+        memcpy(savedescription, p+3, len);
+        // Force terminating 0 in case
+        savedescription[len] = 0;
+      }
+      break;
+    }
+  }
+  break;
       default: // Should not be queued
-	break;
+  break;
       }
 
   { // Requeue remaining packets
@@ -419,10 +423,10 @@ static void CheckQueuedPackets(void)
     packet_header_t **newqueue = NULL;
 
     for (i=0; (unsigned)i<numqueuedpackets; i++)
-      if (doom_ntohl(queuedpacket[i]->tic) > (unsigned)gametic) {
-	newqueue = Z_Realloc(newqueue, ++newnum * sizeof *newqueue, 
-			     PU_STATIC, NULL);
-	newqueue[newnum-1] = queuedpacket[i];
+      if (doom_ntohl(queuedpacket[i]->tic) > gametic) {
+  newqueue = Z_Realloc(newqueue, ++newnum * sizeof *newqueue,
+           PU_STATIC, NULL);
+  newqueue[newnum-1] = queuedpacket[i];
       } else Z_Free(queuedpacket[i]);
 
     Z_Free(queuedpacket);
@@ -438,12 +442,6 @@ void TryRunTics (void)
 
   // Wait for tics to run
   while (1) {
-    if (I_GetTime() - entertime > 5)
-    {
-      C_Ticker();
-      MN_Ticker();
-      return;
-    }
 #ifdef HAVE_NET
     NetUpdate();
 #else
@@ -451,12 +449,17 @@ void TryRunTics (void)
 #endif
     runtics = (server ? remotetic : maketic) - gametic;
     if (!runtics) {
-      I_uSleep(1000);
-      if (I_GetTime() - entertime > 10)
-      {
-	      C_Ticker();
-	      MN_Ticker();
-        return;
+      if (server) I_WaitForPacket(ms_to_next_tick);
+      else I_uSleep(ms_to_next_tick*1000);
+      if (I_GetTime() - entertime > 10) {
+        remotesend--;
+	if (server) {
+	  char buf[sizeof(packet_header_t)+1];
+	  packet_set((packet_header_t *)buf, PKT_RETRANS, remotetic);
+	  buf[sizeof(buf)-1] = consoleplayer;
+	  I_SendPacket((packet_header_t *)buf, sizeof buf);
+	}
+        M_Ticker(); return;
       }
     } else break;
   }
@@ -467,10 +470,8 @@ void TryRunTics (void)
 #endif
     if (advancedemo)
       D_DoAdvanceDemo ();
-    C_Ticker ();
-    MN_Ticker ();
+    M_Ticker ();
     G_Ticker ();
-    V_FPSTicker();
     gametic++;
 #ifdef HAVE_NET
     NetUpdate(); // Keep sending our tics to avoid stalling remote nodes
@@ -487,7 +488,7 @@ void D_QuitNetGame (void)
 
   if (!server) return;
   buf[sizeof(packet_header_t)] = consoleplayer;
-  packet->type = PKT_QUIT; packet->tic = doom_htonl(gametic);
+  packet_set(packet, PKT_QUIT, gametic);
 
   for (i=0; i<4; i++) {
     I_SendPacket(packet, 1 + sizeof(packet_header_t));
