@@ -1,4 +1,4 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
@@ -8,7 +8,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +21,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -35,6 +35,7 @@
 #define __DOOMDATA__
 
 // The most basic types we use, portability.
+#include "config.h"
 #include "doomtype.h"
 
 //
@@ -59,14 +60,6 @@ enum {
   ML_BLOCKMAP           // LUT, motion clipping, walls/grid element
 };
 
-#ifdef _MSC_VER
-#define GCC_PACKED
-#else //_MSC_VER
-/* we might want to make this sensitive to whether configure has detected
-   a build with GCC */
-#define GCC_PACKED __attribute__((packed))
-#endif //_MSC_VER
-
 #ifdef _MSC_VER // proff: This is the same as __attribute__ ((packed)) in GNUC
 #pragma pack(push)
 #pragma pack(1)
@@ -74,30 +67,30 @@ enum {
 
 // A single Vertex.
 typedef struct {
-  short x,y GCC_PACKED;
-} GCC_PACKED mapvertex_t;
+  short x,y;
+} PACKEDATTR mapvertex_t;
 
 // A SideDef, defining the visual appearance of a wall,
 // by setting textures and offsets.
 typedef struct {
-  short textureoffset GCC_PACKED;
-  short rowoffset GCC_PACKED;
-  char  toptexture[8] GCC_PACKED;
-  char  bottomtexture[8] GCC_PACKED;
-  char  midtexture[8] GCC_PACKED;
-  short sector GCC_PACKED;  // Front sector, towards viewer.
-} GCC_PACKED mapsidedef_t;
+  short textureoffset;
+  short rowoffset;
+  char  toptexture[8];
+  char  bottomtexture[8];
+  char  midtexture[8];
+  short sector;  // Front sector, towards viewer.
+} PACKEDATTR mapsidedef_t;
 
 // A LineDef, as used for editing, and as input to the BSP builder.
 
 typedef struct {
-  short v1 GCC_PACKED;
-  short v2 GCC_PACKED;
-  short flags GCC_PACKED;
-  short special GCC_PACKED;
-  short tag GCC_PACKED;
-  short sidenum[2] GCC_PACKED;  // sidenum[1] will be -1 if one sided
-} GCC_PACKED maplinedef_t;
+  short v1;
+  short v2;
+  short flags;
+  short special;
+  short tag;
+  short sidenum[2];  // sidenum[1] will be -1 if one sided
+} PACKEDATTR maplinedef_t;
 
 //
 // LineDef attributes.
@@ -145,31 +138,31 @@ typedef struct {
 
 // Sector definition, from editing.
 typedef struct {
-  short floorheight GCC_PACKED;
-  short ceilingheight GCC_PACKED;
-  char  floorpic[8] GCC_PACKED;
-  char  ceilingpic[8] GCC_PACKED;
-  short lightlevel GCC_PACKED;
-  short special GCC_PACKED;
-  short tag GCC_PACKED;
-} GCC_PACKED mapsector_t;
+  short floorheight;
+  short ceilingheight;
+  char  floorpic[8];
+  char  ceilingpic[8];
+  short lightlevel;
+  short special;
+  short tag;
+} PACKEDATTR mapsector_t;
 
 // SubSector, as generated by BSP.
 typedef struct {
-  unsigned short numsegs GCC_PACKED;
-  unsigned short firstseg GCC_PACKED;    // Index of first one; segs are stored sequentially.
-} GCC_PACKED mapsubsector_t;
+  unsigned short numsegs;
+  unsigned short firstseg;    // Index of first one; segs are stored sequentially.
+} PACKEDATTR mapsubsector_t;
 
 // LineSeg, generated by splitting LineDefs
 // using partition lines selected by BSP builder.
 typedef struct {
-  short v1 GCC_PACKED;
-  short v2 GCC_PACKED;
-  short angle GCC_PACKED;
-  short linedef GCC_PACKED;
-  short side GCC_PACKED;
-  short offset GCC_PACKED;
-} GCC_PACKED mapseg_t;
+  short v1;
+  short v2;
+  short angle;
+  short linedef;
+  short side;
+  short offset;
+} PACKEDATTR mapseg_t;
 
 // BSP node structure.
 
@@ -177,25 +170,25 @@ typedef struct {
 #define NF_SUBSECTOR    0x8000
 
 typedef struct {
-  short x GCC_PACKED;  // Partition line from (x,y) to x+dx,y+dy)
-  short y GCC_PACKED;
-  short dx GCC_PACKED;
-  short dy GCC_PACKED;
+  short x;  // Partition line from (x,y) to x+dx,y+dy)
+  short y;
+  short dx;
+  short dy;
   // Bounding box for each child, clip against view frustum.
-  short bbox[2][4] GCC_PACKED;
+  short bbox[2][4];
   // If NF_SUBSECTOR its a subsector, else it's a node of another subtree.
-  unsigned short children[2] GCC_PACKED;
-} GCC_PACKED mapnode_t;
+  unsigned short children[2];
+} PACKEDATTR mapnode_t;
 
 // Thing definition, position, orientation and type,
 // plus skill/visibility flags and attributes.
 typedef struct {
-  short x GCC_PACKED;
-  short y GCC_PACKED;
-  short angle GCC_PACKED;
-  short type GCC_PACKED;
-  short options GCC_PACKED;
-} GCC_PACKED mapthing_t;
+  short x;
+  short y;
+  short angle;
+  short type;
+  short options;
+} PACKEDATTR mapthing_t;
 
 #ifdef _MSC_VER
 #pragma pack(pop)
