@@ -1,4 +1,4 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
@@ -6,9 +6,9 @@
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
- *  Copyright (C) 1999-2002 by
+ *  Copyright (C) 1999-2006 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +21,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -39,12 +39,10 @@
 
 // We need globally shared data structures,
 //  for defining the global state variables.
-#include "doomdata.h"
 #include "d_net.h"
 
 // We need the playr data structure as well.
 #include "d_player.h"
-#include "p_chase.h"
 
 #ifdef __GNUG__
 #pragma interface
@@ -212,13 +210,12 @@ extern  int viewangleoffset;
 // Player taking events, and displaying.
 extern  int consoleplayer;
 extern  int displayplayer;
-extern camera_t* camera;
 
 // -------------------------------------
 // Scores, rating.
 // Statistics on a given map, for intermission.
 //
-extern  int totalkills;
+extern  int totalkills, totallive;
 extern  int totalitems;
 extern  int totalsecret;
 
@@ -279,6 +276,10 @@ extern int maxammo[];
 // Internal parameters, used for engine.
 //
 
+// File handling stuff.
+extern  char    basedefault[];
+extern  FILE   *debugfile;
+
 // if true, load all graphics at level load
 extern  boolean precache;
 
@@ -310,6 +311,8 @@ extern  int        maketic;
 extern  ticcmd_t   netcmds[][BACKUPTICS];
 extern  int        ticdup;
 
+extern thinker_t thinkercap;  // Both the head and tail of the thinker list
+
 //-----------------------------------------------------------------------------
 
 // v1.1-like pitched sounds
@@ -359,6 +362,4 @@ extern int monster_infighting, default_monster_infighting;
 
 extern int monkeys, default_monkeys;
 
-extern int HelperThing;          // type of thing to use for helper
-
 #endif
