@@ -1,4 +1,4 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
@@ -6,9 +6,9 @@
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
- *  Copyright (C) 1999-2002 by
+ *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,19 +21,19 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
- *      Startup and quit functions. Handles signals, inits the 
- *      memory management, then calls D_DoomMain. Also contains 
+ *      Startup and quit functions. Handles signals, inits the
+ *      memory management, then calls D_DoomMain. Also contains
  *      I_Init which does other system-related startup stuff.
  *
  *-----------------------------------------------------------------------------
  */
 
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -48,11 +48,10 @@
 #include "m_random.h"
 #include "doomstat.h"
 #include "g_game.h"
-#include "g_config.h"
+#include "m_misc.h"
 #include "i_sound.h"
 #include "i_main.h"
 #include "lprintf.h"
-#include "c_runcmd.h"
 #ifdef USE_SDL
 #include "SDL.h"
 #endif
@@ -61,6 +60,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+int broken_pipe;
+
 /* Most of the following has been rewritten by Lee Killough
  *
  * I_GetTime
@@ -68,13 +69,7 @@
  * cphipps - much made static
  */
 
-// how long to wait showing endoom in seconds
-int endoom_delay = 1;
-CONSOLE_INT(i_endoom_delay, endoom_delay, NULL, 0, 10, NULL, 0) {}
-
 int realtic_clock_rate = 100;
-CONSOLE_INT(i_gamespeed, realtic_clock_rate, NULL, 1, 10000, NULL, 0) {}
-
 static int_64_t I_GetTime_Scale = 1<<24;
 
 static int I_GetTime_Scaled(void)
@@ -116,7 +111,7 @@ void I_Init(void)
     else
       I_GetTime = I_GetTime_RealTime;
 
-  { 
+  {
     /* killough 2/21/98: avoid sound initialization if no sound & no music */
     extern boolean nomusicparm, nosfxparm;
     if (!(nomusicparm && nosfxparm))
@@ -130,6 +125,14 @@ static void I_SignalHandler(int s)
 {
   char buf[2048];
 
+#ifdef SIGPIPE
+  /* CPhipps - report but don't crash on SIGPIPE */
+  if (s == SIGPIPE) {
+    fprintf(stderr, "Broken pipe\n");
+    broken_pipe = 1;
+    return;
+  }
+#endif
   signal(s,SIG_IGN);  /* Ignore future instances of this signal.*/
 
   strcpy(buf,"Exiting on signal: ");
@@ -148,7 +151,7 @@ static void I_SignalHandler(int s)
 
 /* killough 2/22/98: Add support for ENDBOOM, which is PC-specific
  *
- * this converts BIOS color codes to ANSI codes.  
+ * this converts BIOS color codes to ANSI codes.
  * Its not pretty, but it does the job - rain
  * CPhipps - made static
  */
@@ -182,12 +185,12 @@ inline static int convert(int color, int *bold)
 
 /* CPhipps - flags controlling ENDOOM behaviour */
 enum {
-  endoom_colours = 1, 
-  endoom_nonasciichars = 2, 
+  endoom_colours = 1,
+  endoom_nonasciichars = 2,
   endoom_droplastline = 4
 };
 
-unsigned int endoom_mode = 5;
+unsigned int endoom_mode;
 
 static void PrintVer(void)
 {
@@ -207,15 +210,15 @@ static void I_EndDoom(void)
   lump_eb = W_CheckNumForName("ENDBOOM");/* jff 4/1/98 sign our work    */
   lump_ed = W_CheckNumForName("ENDOOM"); /* CPhipps - also maybe ENDOOM */
 
-  if (lump_eb == -1) 
+  if (lump_eb == -1)
     lump = lump_ed;
-  else if (lump_ed == -1) 
+  else if (lump_ed == -1)
     lump = lump_eb;
   else
   { /* Both ENDOOM and ENDBOOM are present */
 #define LUMP_IS_NEW(num) (!((lumpinfo[num].source == source_iwad) || (lumpinfo[num].source == source_auto_load)))
-    switch ((LUMP_IS_NEW(lump_ed) ? 1 : 0 ) | 
-	    (LUMP_IS_NEW(lump_eb) ? 2 : 0)) {
+    switch ((LUMP_IS_NEW(lump_ed) ? 1 : 0 ) |
+      (LUMP_IS_NEW(lump_eb) ? 2 : 0)) {
     case 1:
       lump = lump_ed;
       break;
@@ -238,7 +241,7 @@ static void I_EndDoom(void)
     int oldbg = -1, oldcolor = -1, bold = 0, oldbold = -1, color = 0;
 #ifndef _WIN32
     if (endoom_mode & endoom_nonasciichars)
-	    /* switch to secondary charset, and set to cp437 (IBM charset) */
+      /* switch to secondary charset, and set to cp437 (IBM charset) */
       printf("\e)K\016");
 #endif /* _WIN32 */
 
@@ -271,16 +274,16 @@ static void I_EndDoom(void)
           color = convert(color, &bold);
           if (oldbold != bold)
           {
-	          oldbold = bold;
-		  printf("\e[%cm", bold + '0');
-		  if (!bold) oldbg = -1;
+            oldbold = bold;
+      printf("\e[%cm", bold + '0');
+      if (!bold) oldbg = -1;
           }
           /* we buffer everything or output is horrendously slow */
           printf("\e[%dm", color + 30);
           bold = 0;
         }
         /* background color */
-        color = endoom[i][1] / 16; 
+        color = endoom[i][1] / 16;
         if (color != oldbg)
         {
           oldbg = color;
@@ -299,7 +302,7 @@ static void I_EndDoom(void)
     lprintf(LO_INFO,"\b"); /* hack workaround for extra newline at bottom of screen */
     lprintf(LO_INFO,"\r");
     if (endoom_mode & endoom_nonasciichars)
-      printf("%c",'\017'); /* restore primary charset */
+      putchar('\017'); /* restore primary charset */
 #endif /* _WIN32 */
     W_UnlockLumpNum(lump);
   }
@@ -308,14 +311,14 @@ static void I_EndDoom(void)
     puts("\e[0m"); /* cph - reset colours */
   PrintVer();
 #else /* _WIN32 */
-  I_uSleep(endoom_delay * 1000000); // CPhipps - don't thrash cpu in this loop
+  I_uSleep(3000000); // CPhipps - don't thrash cpu in this loop
 #endif /* _WIN32 */
 }
 
 static int has_exited;
 
 /* I_SafeExit
- * This function is called instead of exit() by functions that might be called 
+ * This function is called instead of exit() by functions that might be called
  * during the exit process (i.e. after exit() has already been called)
  * Prevent infinitely recursive exits -- killough
  */
@@ -324,7 +327,7 @@ void I_SafeExit(int rc)
 {
   if (!has_exited)    /* If it hasn't exited yet, exit now -- killough */
     {
-      has_exited=rc ? 2 : 1;   
+      has_exited=rc ? 2 : 1;
       exit(rc);
     }
 }
@@ -338,9 +341,7 @@ void I_Quit (void)
     I_EndDoom();
     if (demorecording)
       G_CheckDemoStatus();
-    //M_SaveDefaults ();
-    //G_SaveDefaults ();
-    W_DoneCache();
+    M_SaveDefaults ();
   }
 }
 
@@ -354,26 +355,27 @@ int main(int argc, char **argv)
 #ifdef SECURE_UID
   /* First thing, revoke setuid status (if any) */
   stored_euid = geteuid();
-  if (getuid() != stored_euid) 
-    if (seteuid(getuid()) < 0) 
+  if (getuid() != stored_euid)
+    if (seteuid(getuid()) < 0)
       fprintf(stderr, "Failed to revoke setuid\n");
     else
       fprintf(stderr, "Revoked uid %d\n",stored_euid);
 #endif
+
+  myargc = argc;
+  myargv = argv;
+
 #ifdef _WIN32
-  /* initialize the console window */
-  Init_ConsoleWin();
-  atexit(Done_ConsoleWin);
+  if (!M_CheckParm("-nodraw")) {
+    /* initialize the console window */
+    Init_ConsoleWin();
+    atexit(Done_ConsoleWin);
+  }
 #endif
   /* Version info */
   lprintf(LO_INFO,"\n");
   PrintVer();
 
-  myargc = argc;
-  myargv = argv;
-
-  /* cph - Z_Close must be done after I_Quit, so we register it first. */
-  atexit(Z_Close);
   /*
      killough 1/98:
 
@@ -390,37 +392,30 @@ int main(int argc, char **argv)
      left in an unstable state.
   */
 
+  Z_Init();                  /* 1/18/98 killough: start up memory stuff first */
+
   atexit(I_Quit);
-  
-#ifndef _DEBUG // POPE  
+#ifndef _DEBUG
   signal(SIGSEGV, I_SignalHandler);
+#ifdef SIGPIPE
+  signal(SIGPIPE, I_SignalHandler); /* CPhipps - add SIGPIPE, as this is fatal */
+#endif
   signal(SIGTERM, I_SignalHandler);
+  signal(SIGILL,  I_SignalHandler);
   signal(SIGFPE,  I_SignalHandler);
   signal(SIGILL,  I_SignalHandler);
   signal(SIGINT,  I_SignalHandler);  /* killough 3/6/98: allow CTRL-BRK during init */
   signal(SIGABRT, I_SignalHandler);
 #endif
-  
+
   /* cphipps - call to video specific startup code */
-  I_PreInitGraphics();
+  if (!(M_CheckParm("-nodraw") && M_CheckParm("-nosound")))
+    I_PreInitGraphics();
+
+  /* 2/2/98 Stan
+   * Must call this here.  It's required by both netgames and i_video.c.
+   */
 
   D_DoomMain ();
   return 0;
 }
-
-extern void I_Video_AddCommands();
-//extern void I_Sound_AddCommands();
-//extern void I_Input_AddCommands();
-//extern void Ser_AddCommands();
-
-// add system specific commands
-void I_AddCommands()
-{
-  //C_AddCommand(i_ledsoff);
-  C_AddCommand(i_endoom_delay);
-  C_AddCommand(i_gamespeed);
-  
-  I_Video_AddCommands();
-  //I_Sound_AddCommands();
-  //Ser_AddCommands();
-}
