@@ -1,4 +1,4 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
@@ -8,7 +8,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,15 +21,15 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
- *  Low level network interface. 
+ *  Low level network interface.
  *-----------------------------------------------------------------------------*/
 
-#ifdef HAVE_CONFIG_H 
-#include "../config.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #ifdef USE_SDL_NET
@@ -51,7 +51,7 @@
 void I_InitNetwork(void);
 size_t I_GetPacket(packet_header_t* buffer, size_t buflen);
 void I_SendPacket(packet_header_t* packet, size_t len);
-void I_WaitForPacket(void);
+void I_WaitForPacket(int ms);
 
 #ifdef USE_SDL_NET
 UDP_SOCKET I_Socket(Uint16 port);
