@@ -1,4 +1,4 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
@@ -8,7 +8,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +21,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -34,14 +34,11 @@
 
 #include "d_player.h"
 #include "r_data.h"
-#include "p_chase.h"
 
 #ifdef __GNUG__
 #pragma interface
 #endif
 
-extern int screenblocks;
-
 //
 // POV related.
 //
@@ -62,8 +59,6 @@ extern fixed_t  projectiony;
 extern int      validcount;
 extern int      linecount;
 extern int      loopcount;
-extern int      viewheightsec;
-extern camera_t *viewcamera;
 
 //
 // Rendering stats
@@ -88,6 +83,7 @@ extern boolean rendering_stats;
 #define LIGHTZSHIFT       20
 
 // killough 3/20/98: Allow colormaps to be dynamic (e.g. underwater)
+extern lighttable_t *(*scalelight)[MAXLIGHTSCALE];
 extern lighttable_t *(*zlight)[MAXLIGHTZ];
 extern lighttable_t *fullcolormap;
 extern int numcolormaps;    // killough 4/4/98: dynamic number of maps
@@ -106,14 +102,14 @@ extern lighttable_t *fixedcolormap;
 // Function pointer to switch refresh/drawing functions.
 //
 
-extern void (*colfunc)(); // Removed void parameter - POPE
+extern void (*colfunc)(void);
 
 //
 // Utility functions.
 //
 
-const int R_PointOnSide(fixed_t x, fixed_t y, const node_t *node);
-const int R_PointOnSegSide(fixed_t x, fixed_t y, const seg_t *line);
+CONSTFUNC int R_PointOnSide(fixed_t x, fixed_t y, const node_t *node);
+CONSTFUNC int R_PointOnSegSide(fixed_t x, fixed_t y, const seg_t *line);
 angle_t R_PointToAngle(fixed_t x, fixed_t y);
 angle_t R_PointToAngle2(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2);
 subsector_t *R_PointInSubsector(fixed_t x, fixed_t y);
@@ -122,11 +118,9 @@ subsector_t *R_PointInSubsector(fixed_t x, fixed_t y);
 // REFRESH - the actual rendering functions.
 //
 
-void R_RenderPlayerView(player_t *player, camera_t* viewcamera);
-void R_InitColFunc();
+void R_RenderPlayerView(player_t *player);   // Called by G_Drawer.
 void R_Init(void);                           // Called by startup code.
 void R_SetViewSize(int blocks);              // Called by M_Responder.
 void R_ExecuteSetViewSize(void);             // cph - called by D_Display to complete a view resize
-angle_t R_WadToAngle(int wadangle);
 
 #endif
