@@ -92,7 +92,7 @@ typedef struct
 {
   // WARNING: order of some fields important (see info.c).
 
-  char  name[8];
+  char  name[9];
   int   size;
 
   // killough 1/31/98: hash table fields, used for ultra-fast hash table lookup
@@ -105,7 +105,7 @@ typedef struct
     ns_flats,
     ns_colormaps,
     ns_prboom
-  } namespace;
+  } li_namespace; // haleyjd 05/21/02: renamed from "namespace"
 
   wadfile_info_t *wadfile;
   int position;
@@ -127,9 +127,6 @@ void    W_ReadLump (int lump, void *dest);
 const void* W_CacheLumpNum (int lump);
 void    W_UnlockLumpNum(int lump);
 
-/* cph - special version to return lump with padding, for sound lumps */
-const void * W_CacheLumpNumPadded(int lump, size_t len, unsigned char pad);
-
 // CPhipps - convenience macros
 //#define W_CacheLumpNum(num) (W_CacheLumpNum)((num),1)
 #define W_CacheLumpName(name) W_CacheLumpNum (W_GetNumForName(name))
