@@ -41,7 +41,7 @@
 
 // use config.h if autoconf made one -- josh
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -51,6 +51,7 @@
 #include "doomstat.h"
 #include "m_argv.h"
 #include "v_video.h"
+#include "g_game.h"
 #include "lprintf.h"
 
 #ifdef DJGPP
@@ -91,10 +92,9 @@ typedef struct memblock {
   struct memblock *next,*prev;
   size_t size;
   void **user;
-  unsigned char tag,vm;
+  unsigned char tag;
 
 #ifdef INSTRUMENTED
-  unsigned short extra;
   const char *file;
   int line;
 #endif
@@ -106,67 +106,37 @@ typedef struct memblock {
  * 64bit architectures */
 static const size_t HEADER_SIZE = (sizeof(memblock_t)+CHUNK_SIZE-1) & ~(CHUNK_SIZE-1);
 
-static memblock_t *rover;                // roving pointer to memory blocks
-static memblock_t *zone;                 // pointer to first block
-static memblock_t *zonebase;             // pointer to entire zone memory
 static memblock_t *blockbytag[PU_MAX];
 
+static int memory_size = 8192*1024;
+static int free_memory = 0;
+
 #ifdef INSTRUMENTED
 
 // statistics for evaluating performance
-static size_t free_memory;
-static size_t active_memory;
-static size_t purgable_memory;
-static size_t inactive_memory;
-static size_t virtual_memory;
+static int active_memory = 0;
+static int purgable_memory = 0;
 
 void Z_DrawStats(void)            // Print allocation statistics
 {
-  char buffer[1024];
-
-  unsigned long total_memory = free_memory + active_memory +
-                               purgable_memory + inactive_memory +
-                               virtual_memory;
+  unsigned long total_memory = free_memory + memory_size + active_memory + purgable_memory;
   double s = 100.0 / total_memory;
 
   if (gamestate != GS_LEVEL)
     return;
 
-  sprintf(buffer,FC_GRAY
-          "%-5u\n"
-          "%-5u\n"
-          "%-5u\n"
-          "%-5u\n"
-          "%-5u\n"
-          "%-5lu\n",
+  doom_printf("%-5i\t%6.01f%%\tstatic\n"
+          "%-5i\t%6.01f%%\tpurgable\n"
+          "%-5i\t%6.01f%%\tfree\n"
+          "%-5li\t\ttotal\n",
           active_memory,
+          active_memory*s,
           purgable_memory,
-          free_memory,
-          inactive_memory,
-          virtual_memory,
+          purgable_memory*s,
+          (free_memory + memory_size),
+          (free_memory + memory_size)*s,
           total_memory
           );
-  V_WriteTextXYGap(buffer, 0, 16, -1, -1);
-  sprintf(buffer,FC_GRAY
-          "%6.01f%%\n"
-          "%6.01f%%\n"
-          "%6.01f%%\n"
-          "%6.01f%%\n"
-          "%6.01f%%\n",
-          active_memory*s,
-          purgable_memory*s,
-          free_memory*s,
-          inactive_memory*s,
-          virtual_memory*s
-          );
-  V_WriteTextXYGap(buffer, 45, 16, -1, -1);
-  V_WriteTextXYGap(FC_GRAY
-                   "static\n"
-                   "purgable\n"
-                   "free\n"
-                   "fragmentary\n"
-                   "virtual\n"
-                   "total\n", 90, 16, -1, -1);
 }
 
 #ifdef HEAPDUMP
@@ -175,52 +145,57 @@ void W_PrintLump(FILE* fp, void* p);
 void Z_DumpMemory(void)
 {
   static int dump;
-  memblock_t* block = zone;
   char buf[80];
   FILE* fp;
   size_t total_cache = 0, total_free = 0, total_malloc = 0;
+  int tag;
 
   sprintf(buf, "memdump.%d", dump++);
   fp = fopen(buf, "w");
-  if (block)
-  do {
-    switch (block->tag) {
-    case PU_FREE: 
-      fprintf(fp, "free %d\n", block->size);
-      total_free += block->size;
-      break;
-    case PU_CACHE:
-      fprintf(fp, "cache %s:%d:%d\n", block->file, block->line, block->size);
-      total_cache += block->size;
-      break;
-    case PU_LEVEL:
-      fprintf(fp, "level %s:%d:%d\n", block->file, block->line, block->size);
-      total_malloc += block->size;
-      break;
-    default:
-      fprintf(fp, "malloc %s:%d:%d", block->file, block->line, block->size);
-      total_malloc += block->size;
-      if (block->file)
-        if (strstr(block->file,"w_wad.c"))
-	  W_PrintLump(fp, (char*)block + HEADER_SIZE);
-      fputc('\n', fp);
-      break;
+  for (tag = PU_FREE; tag < PU_MAX; tag++)
+  {
+    memblock_t* end_block, *block;
+    block = blockbytag[tag];
+    if (!block)
+      continue;
+    end_block = block->prev;
+    while (1)
+    {
+      switch (block->tag) {
+      case PU_FREE: 
+        fprintf(fp, "free %d\n", block->size);
+        total_free += block->size;
+        break;
+      case PU_CACHE:
+        fprintf(fp, "cache %s:%d:%d\n", block->file, block->line, block->size);
+        total_cache += block->size;
+        break;
+      case PU_LEVEL:
+        fprintf(fp, "level %s:%d:%d\n", block->file, block->line, block->size);
+        total_malloc += block->size;
+        break;
+      default:
+        fprintf(fp, "malloc %s:%d:%d", block->file, block->line, block->size);
+        total_malloc += block->size;
+        if (block->file)
+          if (strstr(block->file,"w_memcache.c"))
+            W_PrintLump(fp, (char*)block + HEADER_SIZE);
+        fputc('\n', fp);
+        break;
+      }
+      if (block == end_block)
+        break;
+      block=block->next;
     }
-    block=block->next;
-    if (((int)block->file < 0x00001000) && (block->file != NULL) && (block->tag != 0)) {
-	    block->file = NULL;
-    }
-  } while (block != zone);
+  }
   fprintf(fp, "malloc %d, cache %d, free %d, total %d\n",
-	  total_malloc, total_cache, total_free, 
-	  total_malloc + total_cache + total_free);
+    total_malloc, total_cache, total_free, 
+    total_malloc + total_cache + total_free);
   fclose(fp);
 }
 #endif
 #endif
 
-size_t zone_size=8192;
-
 #ifdef INSTRUMENTED
 
 // killough 4/26/98: Add history information
@@ -263,12 +238,15 @@ void Z_DumpHistory(char *buf)
 
 void Z_Close(void)
 {
+#if 0
   (free)(zonebase);
   zone = rover = zonebase = NULL;
+#endif
 }
 
 void Z_Init(void)
 {
+#if 0
   size_t size = zone_size*1000;
 
 #ifdef HAVE_MMAP
@@ -290,7 +268,7 @@ void Z_Init(void)
     I_Error("Z_Init: Failed on allocation of %lu bytes", (unsigned long)size);
 
   lprintf(LO_INFO,"Z_Init : Allocated %lukb zone memory\n",
-		  (long unsigned)size / 1000);
+      (long unsigned)size / 1000);
 
   // Align on cache boundary
 
@@ -314,6 +292,7 @@ void Z_Init(void)
 #ifdef HEAPDUMP
   atexit(Z_DumpMemory);
 #endif
+#endif
 }
 
 /* Z_Malloc
@@ -330,16 +309,13 @@ void Z_Init(void)
 
 void *(Z_Malloc)(size_t size, int tag, void **user
 #ifdef INSTRUMENTED
-		 , const char *file, int line
+     , const char *file, int line
 #endif
-		 )
+     )
 {
-  register memblock_t *block;
-  memblock_t *start, *first_of_free;
-  register size_t contig_free = 0;
+  memblock_t *block = NULL;
 
 #ifdef INSTRUMENTED
-  size_t size_orig = size;
 #ifdef CHECKHEAP
   Z_CheckHeap();
 #endif
@@ -355,7 +331,7 @@ void *(Z_Malloc)(size_t size, int tag, void **user
 #ifdef INSTRUMENTED
              "Source: %s:%d", file, line
 #endif
-	     );
+       );
 #endif
 
   if (!size)
@@ -363,129 +339,70 @@ void *(Z_Malloc)(size_t size, int tag, void **user
 
   size = (size+CHUNK_SIZE-1) & ~(CHUNK_SIZE-1);  // round to chunk size
 
-  block = rover;
-
-  /* cph - allow memory allocation even before Z_Init;
-   *  just drop through to the malloc(3) fallback
-   */
-  if (block) {
-   if (block->prev->tag == PU_FREE)
-    block = block->prev;
-
-   start = block;
-   first_of_free = NULL;
-
-   do {
-    /* If we just wrapped, we're not contiguous with the previous block */
-    if (block == zone) contig_free = 0;
-
-    if (block->tag < PU_PURGELEVEL && block->tag != PU_FREE) {
-      /* Not free(able), so no free space here */
-      contig_free = 0;
-    } else {
-      /* Add to contiguous chunk of free space */
-      if (!contig_free) first_of_free = block;
-      contig_free += block->size;
-
-      /* First fit */
-      if (contig_free >= size)
-	break;
-    }
-   }
-   while ((block = block->next) != start);   // detect cycles as failure
-  }
-
-  if (contig_free >= size) {
-    /* We have a block of free(able) memory on the heap which will suffice */
-    block = first_of_free;
-
-    /* If the previous block is adjacent and free, step back and include it */
-    if (block != zone && block->prev->tag == PU_FREE) 
-      block = block->prev;
-
-    /* Free current block if needed */
-    if (block->tag != PU_FREE) Z_Free((char *) block + HEADER_SIZE);
-
-    /* Note: guaranteed that block->prev is either 
-     * not free or not contiguous 
-     *
-     * At every step, block->next must be not free, else it would 
-     *  have been merged with our block 
-     * No range check needed because we know it works by the previous loop */
-    while (block->size < size)
-      Z_Free((char *)(block->next) + HEADER_SIZE);
-
-    /* Now, carve up the block */
+  if ((free_memory + memory_size) < (int)(size + HEADER_SIZE))
+  {
+    memblock_t *end_block;
+    block = blockbytag[PU_CACHE];
+    if (block)
     {
-      size_t extra = block->size - size;
-      if (extra >= MIN_BLOCK_SPLIT + HEADER_SIZE) {
-	memblock_t *newb = (memblock_t *)((char *) block +
-					  HEADER_SIZE + size);
-	
-	(newb->next = block->next)->prev = newb;
-	(newb->prev = block)->next = newb;          // Split up block
-	block->size = size;
-	newb->size = extra - HEADER_SIZE;
-	newb->tag = PU_FREE;
-	newb->vm = 0;
-	
+      end_block = block->prev;
+      while (1)
+      {
+        memblock_t *next = block->next;
 #ifdef INSTRUMENTED
-	inactive_memory += HEADER_SIZE;
-	free_memory -= HEADER_SIZE;
-#endif
-      }
-      
-      rover = block->next;           // set roving pointer for next search
-      
-#ifdef INSTRUMENTED
-      inactive_memory += block->extra = block->size - size_orig;
-      if (tag >= PU_PURGELEVEL)
-	purgable_memory += size_orig;
-      else
-	active_memory += size_orig;
-      free_memory -= block->size;
-#endif
-    }
-  } else {
-    /* Allocate a vm block * 
-     * We've run out of physical memory, or so we think.
-     * Although less efficient, we'll just use ordinary malloc.
-     * This will squeeze the remaining juice out of this machine
-     * and start cutting into virtual memory if it has it.
-     */
-    
-#ifdef HAVE_LIBDMALLOC
-    while (!(block = _malloc_leap(file,line,size + HEADER_SIZE))) {
+        (Z_Free)((char *) block + HEADER_SIZE, file, line);
 #else
-    while (!(block = (malloc)(size + HEADER_SIZE))) {
+        (Z_Free)((char *) block + HEADER_SIZE);
 #endif
-      if (!blockbytag[PU_CACHE])
-        I_Error ("Z_Malloc: Failure trying to allocate %lu bytes"
-#ifdef INSTRUMENTED
-                 "\nSource: %s:%d"
-#endif
-		 ,(unsigned long) size
-#ifdef INSTRUMENTED
-		 , file, line
-#endif
-		 );
-      Z_FreeTags(PU_CACHE,PU_CACHE);
+        if (((free_memory + memory_size) >= (int)(size + HEADER_SIZE)) || (block == end_block))
+          break;
+        block = next;               // Advance to next block
+      }
     }
-
-    if ((block->next = blockbytag[tag]))
-      block->next->prev = (memblock_t *) &block->next;
-    blockbytag[tag] = block;
-    block->prev = (memblock_t *) &blockbytag[tag];
-    block->vm = 1;
-    
-#ifdef INSTRUMENTED
-    virtual_memory += size + HEADER_SIZE;
-#endif
-    /* cph - the next line was lost in the #ifdef above, and also added an 
-     *  extra HEADER_SIZE to block->size, which was incorrect */
-    block->size = size; 
+    block = NULL;
   }
 
+#ifdef HAVE_LIBDMALLOC
+  while (!(block = dmalloc_malloc(file,line,size + HEADER_SIZE,DMALLOC_FUNC_MALLOC,0,0))) {
+#else
+  while (!(block = (malloc)(size + HEADER_SIZE))) {
+#endif
+    if (!blockbytag[PU_CACHE])
+      I_Error ("Z_Malloc: Failure trying to allocate %lu bytes"
+#ifdef INSTRUMENTED
+               "\nSource: %s:%d"
+#endif
+               ,(unsigned long) size
+#ifdef INSTRUMENTED
+               , file, line
+#endif
+      );
+    Z_FreeTags(PU_CACHE,PU_CACHE);
+  }
+
+  if (!blockbytag[tag])
+  {
+    blockbytag[tag] = block;
+    block->next = block->prev = block;
+  }
+  else
+  {
+    blockbytag[tag]->prev->next = block;
+    block->prev = blockbytag[tag]->prev;
+    block->next = blockbytag[tag];
+    blockbytag[tag]->prev = block;
+  }
+    
+  block->size = size;
+
+#ifdef INSTRUMENTED
+  if (tag >= PU_PURGELEVEL)
+    purgable_memory += block->size;
+  else
+    active_memory += block->size;
+#endif
+  free_memory -= block->size;
+
 #ifdef INSTRUMENTED
   block->file = file;
   block->line = line;
@@ -501,18 +418,22 @@ void *(Z_Malloc)(size_t size, int tag, void **user
     *user = block;            // set user to point to new block
   
 #ifdef INSTRUMENTED
+  Z_DrawStats();           // print memory allocation stats
   // scramble memory -- weed out any bugs
   memset(block, gametic & 0xff, size);
 #endif
+
   return block;
 }
 
 void (Z_Free)(void *p
 #ifdef INSTRUMENTED
-	      , const char *file, int line
+              , const char *file, int line
 #endif
-	      )
+             )
 {
+  memblock_t *block = (memblock_t *)((char *) p - HEADER_SIZE);
+
 #ifdef INSTRUMENTED
 #ifdef CHECKHEAP
   Z_CheckHeap();
@@ -522,104 +443,60 @@ void (Z_Free)(void *p
   history_index[free_history] &= ZONE_HISTORY-1;
 #endif
 
-  if (p)
-    {
-      memblock_t *other, *block = (memblock_t *)((char *) p - HEADER_SIZE);
+  if (!p)
+    return;
+
 
 #ifdef ZONEIDCHECK
-      if (block->id != ZONEID)
-        I_Error("Z_Free: freed a pointer without ZONEID"
+  if (block->id != ZONEID)
+    I_Error("Z_Free: freed a pointer without ZONEID"
 #ifdef INSTRUMENTED
-                "\nSource: %s:%d"
-                "\nSource of malloc: %s:%d"
-                , file, line, block->file, block->line
+            "\nSource: %s:%d"
+            "\nSource of malloc: %s:%d"
+            , file, line, block->file, block->line
 #endif
-                );
-      block->id = 0;              // Nullify id so another free fails
+           );
+  block->id = 0;              // Nullify id so another free fails
 #endif
 
+  if (block->user)            // Nullify user if one exists
+    *block->user = NULL;
+
+  if (block == block->next)
+    blockbytag[block->tag] = NULL;
+  else
+    if (blockbytag[block->tag] == block)
+      blockbytag[block->tag] = block->next;
+  block->prev->next = block->next;
+  block->next->prev = block->prev;
+
+  free_memory += block->size;
 #ifdef INSTRUMENTED
-      /* scramble memory -- weed out any bugs */
-      memset(p, gametic & 0xff, block->size);
+  if (block->tag >= PU_PURGELEVEL)
+    purgable_memory -= block->size;
+  else
+    active_memory -= block->size;
+
+  /* scramble memory -- weed out any bugs */
+  memset(block, gametic & 0xff, block->size + HEADER_SIZE);
 #endif
 
-      if (block->user)            // Nullify user if one exists
-        *block->user = NULL;
-
-      if (block->vm)
-        {
-          if ((*(memblock_t **) block->prev = block->next))
-            block->next->prev = block->prev;
-
-#ifdef INSTRUMENTED
-          virtual_memory -= block->size + HEADER_SIZE;
-#endif
 #ifdef HAVE_LIBDMALLOC
-          _free_leap(file,line,block);
+  dmalloc_free(file,line,block,DMALLOC_FUNC_MALLOC);
 #else
-          (free)(block);
+  (free)(block);
 #endif
-        }
-      else
-        {
-
 #ifdef INSTRUMENTED
-          free_memory += block->size;
-          inactive_memory -= block->extra;
-          if (block->tag >= PU_PURGELEVEL)
-            purgable_memory -= block->size - block->extra;
-          else
-            active_memory -= block->size - block->extra;
+      Z_DrawStats();           // print memory allocation stats
 #endif
-
-          block->tag = PU_FREE;       // Mark block freed
-
-          if (block != zone)
-            {
-              other = block->prev;        // Possibly merge with previous block
-              if (other->tag == PU_FREE)
-                {
-                  if (rover == block)  // Move back rover if it points at block
-                    rover = other;
-                  (other->next = block->next)->prev = other;
-                  other->size += block->size + HEADER_SIZE;
-                  block = other;
-
-#ifdef INSTRUMENTED
-                  inactive_memory -= HEADER_SIZE;
-                  free_memory += HEADER_SIZE;
-#endif
-                }
-            }
-
-          other = block->next;        // Possibly merge with next block
-          if (other->tag == PU_FREE && other != zone)
-            {
-              if (rover == other) // Move back rover if it points at next block
-                rover = block;
-              (block->next = other->next)->prev = block;
-              block->size += other->size + HEADER_SIZE;
-
-#ifdef INSTRUMENTED
-              inactive_memory -= HEADER_SIZE;
-              free_memory += HEADER_SIZE;
-#endif
-            }
-        }
-    }
 }
 
 void (Z_FreeTags)(int lowtag, int hightag
 #ifdef INSTRUMENTED
-		  , const char *file, int line
+                  , const char *file, int line
 #endif
-		  )
+                 )
 {
-  /* cph - move rover to start of zone; we like to encourage static 
-   * data to stay in one place, at the start of the heap
-   */
-  memblock_t *block = rover = zone;
-
 #ifdef HEAPDUMP
   Z_DumpMemory();
 #endif
@@ -627,70 +504,47 @@ void (Z_FreeTags)(int lowtag, int hightag
   if (lowtag <= PU_FREE)
     lowtag = PU_FREE+1;
 
-  if (block)
-  do               // Scan through list, searching for tags in range
-    if (block->tag >= lowtag && block->tag <= hightag)
-      {
-        memblock_t *prev = block->prev, *cur = block;
-#ifdef INSTRUMENTED
-        (Z_Free)((char *) block + HEADER_SIZE, file, line);
-#else
-        (Z_Free)((char *) block + HEADER_SIZE);
-#endif
-	/* cph - be more careful here, we were skipping blocks!
-	 * If the current block was not merged with the previous, 
-	 *  cur is still a valid pointer, prev->next == cur, and cur is 
-	 *  already free so skip to the next.
-	 * If the current block was merged with the previous, 
-	 *  the next block to analyse is prev->next.
-	 * Note that the while() below does the actual step forward 
-	 */
-        block = (prev->next == cur) ? cur : prev;
-      }
-  while ((block=block->next) != zone);
-
   if (hightag > PU_CACHE)
     hightag = PU_CACHE;
 
   for (;lowtag <= hightag; lowtag++)
-    for (block = blockbytag[lowtag], blockbytag[lowtag] = NULL; block;)
-      {
-        memblock_t *next = block->next;
-
-#ifdef ZONEIDCHECK
-        if (block->id != ZONEID)
-          I_Error("Z_Free: freed a pointer without ZONEID"
+  {
+    memblock_t *block, *end_block;
+    block = blockbytag[lowtag];
+    if (!block)
+      continue;
+    end_block = block->prev;
+    while (1)
+    {
+      memblock_t *next = block->next;
 #ifdef INSTRUMENTED
-                  "\nSource: %s:%d"
-                  "\nSource of malloc: %s:%d"
-                  , file, line, block->file, block->line
+      (Z_Free)((char *) block + HEADER_SIZE, file, line);
+#else
+      (Z_Free)((char *) block + HEADER_SIZE);
 #endif
-                  );
-
-        block->id = 0;              // Nullify id so another free fails
-#endif
-
-#ifdef INSTRUMENTED
-        virtual_memory -= block->size + HEADER_SIZE;
-#endif
-
-        if (block->user)            // Nullify user if one exists
-          *block->user = NULL;
-
-        (free)(block);              // Free the block
-
-        block = next;               // Advance to next block
-      }
+      if (block == end_block)
+        break;
+      block = next;               // Advance to next block
+    }
+  }
 }
 
 void (Z_ChangeTag)(void *ptr, int tag
 #ifdef INSTRUMENTED
-		   , const char *file, int line
+       , const char *file, int line
 #endif
-		   )
+       )
 {
   memblock_t *block = (memblock_t *)((char *) ptr - HEADER_SIZE);
 
+  // proff - added sanity check, this can happen when an empty lump is locked
+  if (!ptr)
+    return;
+
+  // proff - do nothing if tag doesn't differ
+  if (tag == block->tag)
+    return;
+
 #ifdef INSTRUMENTED
 #ifdef CHECKHEAP
   Z_CheckHeap();
@@ -705,7 +559,7 @@ void (Z_ChangeTag)(void *ptr, int tag
              "\nSource of malloc: %s:%d"
              , file, line, block->file, block->line
 #endif
-             );
+            );
 
   if (tag >= PU_PURGELEVEL && !block->user)
     I_Error ("Z_ChangeTag: an owner is required for purgable blocks\n"
@@ -714,35 +568,45 @@ void (Z_ChangeTag)(void *ptr, int tag
              "\nSource of malloc: %s:%d"
              , file, line, block->file, block->line
 #endif
-             );
+            );
 
 #endif // ZONEIDCHECK
 
-  if (block->vm)
-    {
-      if ((*(memblock_t **) block->prev = block->next))
-        block->next->prev = block->prev;
-      if ((block->next = blockbytag[tag]))
-        block->next->prev = (memblock_t *) &block->next;
-      block->prev = (memblock_t *) &blockbytag[tag];
-      blockbytag[tag] = block;
-    }
+  if (block == block->next)
+    blockbytag[block->tag] = NULL;
   else
-    {
+    if (blockbytag[block->tag] == block)
+      blockbytag[block->tag] = block->next;
+  block->prev->next = block->next;
+  block->next->prev = block->prev;
+
+  if (!blockbytag[tag])
+  {
+    blockbytag[tag] = block;
+    block->next = block->prev = block;
+  }
+  else
+  {
+    blockbytag[tag]->prev->next = block;
+    block->prev = blockbytag[tag]->prev;
+    block->next = blockbytag[tag];
+    blockbytag[tag]->prev = block;
+  }
+
 #ifdef INSTRUMENTED
-      if (block->tag < PU_PURGELEVEL && tag >= PU_PURGELEVEL)
-        {
-          active_memory -= block->size - block->extra;
-          purgable_memory += block->size - block->extra;
-        }
-      else
-        if (block->tag >= PU_PURGELEVEL && tag < PU_PURGELEVEL)
-          {
-            active_memory += block->size - block->extra;
-            purgable_memory -= block->size - block->extra;
-          }
-#endif
+  if (block->tag < PU_PURGELEVEL && tag >= PU_PURGELEVEL)
+  {
+    active_memory -= block->size;
+    purgable_memory += block->size;
+  }
+  else
+    if (block->tag >= PU_PURGELEVEL && tag < PU_PURGELEVEL)
+    {
+      active_memory += block->size;
+      purgable_memory -= block->size;
     }
+#endif
+
   block->tag = tag;
 }
 
@@ -750,7 +614,7 @@ void *(Z_Realloc)(void *ptr, size_t n, int tag, void **user
 #ifdef INSTRUMENTED
                   , const char *file, int line
 #endif
-		  )
+                 )
 {
   void *p = (Z_Malloc)(n, tag, user DA(file, line));
   if (ptr)
@@ -768,7 +632,7 @@ void *(Z_Calloc)(size_t n1, size_t n2, int tag, void **user
 #ifdef INSTRUMENTED
                  , const char *file, int line
 #endif
-		 )
+                )
 {
   return
     (n1*=n2) ? memset((Z_Malloc)(n1, tag, user DA(file, line)), 0, n1) : NULL;
@@ -778,18 +642,19 @@ char *(Z_Strdup)(const char *s, int tag, void **user
 #ifdef INSTRUMENTED
                  , const char *file, int line
 #endif
-		 )
+                )
 {
   return strcpy((Z_Malloc)(strlen(s)+1, tag, user DA(file, line)), s);
 }
 
 void (Z_CheckHeap)(
 #ifdef INSTRUMENTED
-		   const char *file, int line
+       const char *file, int line
 #endif
-		   )
+       )
 {
-  memblock_t *block = zone;   // Start at base of zone mem
+#if 0
+  memblock_t *block;   // Start at base of zone mem
   if (block)
   do {                        // Consistency check (last node treated special)
     if ((block->next != zone &&
@@ -806,8 +671,9 @@ void (Z_CheckHeap)(
 // shouldn't be needed anymore, was just for testing
 #if 0
     if (((int)block->file < 0x00001000) && (block->file != NULL) && (block->tag != 0)) {
-	    block->file = NULL;
+      block->file = NULL;
     }
 #endif
   } while ((block=block->next) != zone);
+#endif
 }
